prompttrail.agent.subroutine package
====================================

Submodules
----------

prompttrail.agent.subroutine.session\_init\_strategy module
-----------------------------------------------------------

.. automodule:: prompttrail.agent.subroutine.session_init_strategy
   :members:
   :undoc-members:
   :show-inheritance:

prompttrail.agent.subroutine.squash\_strategy module
----------------------------------------------------

.. automodule:: prompttrail.agent.subroutine.squash_strategy
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: prompttrail.agent.subroutine
   :members:
   :undoc-members:
   :show-inheritance:
